pub struct InstanceBuffer { /* private fields */ }Expand description
GPU buffer for storing instance data.
Implementations
Sourceimpl InstanceBuffer
impl InstanceBuffer
Sourcepub fn new(
ctx: &WgpuContext,
instances: &[InstanceData],
label: Option<&str>,
) -> Self
pub fn new( ctx: &WgpuContext, instances: &[InstanceData], label: Option<&str>, ) -> Self
Create a new instance buffer from a slice of instance data.
Sourcepub fn with_capacity(
ctx: &WgpuContext,
capacity: u32,
label: Option<&str>,
) -> Self
pub fn with_capacity( ctx: &WgpuContext, capacity: u32, label: Option<&str>, ) -> Self
Create an empty instance buffer with the given capacity.
Sourcepub fn update(
&mut self,
ctx: &WgpuContext,
instances: &[InstanceData],
) -> Result<(), String>
pub fn update( &mut self, ctx: &WgpuContext, instances: &[InstanceData], ) -> Result<(), String>
Update the instance buffer with new data. If the new data is larger than capacity, returns an error.
Sourcepub fn slice(&self) -> BufferSlice<'_>
pub fn slice(&self) -> BufferSlice<'_>
Create a buffer slice for the entire buffer.