pub struct RenderTarget<'a> { /* private fields */ }Expand description
A render target that can be rendered to.
Implementations
Sourceimpl<'a> RenderTarget<'a>
impl<'a> RenderTarget<'a>
Sourcepub fn new(
ctx: &'a WgpuContext,
color_view: &'a TextureView,
depth_view: Option<&'a TextureView>,
width: u32,
height: u32,
format: TextureFormat,
) -> Self
pub fn new( ctx: &'a WgpuContext, color_view: &'a TextureView, depth_view: Option<&'a TextureView>, width: u32, height: u32, format: TextureFormat, ) -> Self
Create a new render target.
Sourcepub fn from_surface(
ctx: &'a WgpuContext,
surface_view: &'a TextureView,
depth_texture: Option<&'a DepthTexture>,
width: u32,
height: u32,
format: TextureFormat,
) -> Self
pub fn from_surface( ctx: &'a WgpuContext, surface_view: &'a TextureView, depth_texture: Option<&'a DepthTexture>, width: u32, height: u32, format: TextureFormat, ) -> Self
Create a render target from a surface texture.
Sourcepub fn format(&self) -> TextureFormat
pub fn format(&self) -> TextureFormat
Get the texture format.
Sourcepub fn begin_render_pass<'p>(
&'a self,
encoder: &'p mut CommandEncoder,
clear: ClearState,
) -> RenderPass<'p>where
'a: 'p,
pub fn begin_render_pass<'p>(
&'a self,
encoder: &'p mut CommandEncoder,
clear: ClearState,
) -> RenderPass<'p>where
'a: 'p,
Create a render pass with the given clear state.
Sourcepub fn clear(&self, clear: ClearState)
pub fn clear(&self, clear: ClearState)
Clear the render target with the given clear state.
Sourcepub fn context(&self) -> &WgpuContext
pub fn context(&self) -> &WgpuContext
Get a reference to the context.
Sourcepub fn color_view(&self) -> &TextureView
pub fn color_view(&self) -> &TextureView
Get the color view.
Sourcepub fn depth_view(&self) -> Option<&TextureView>
pub fn depth_view(&self) -> Option<&TextureView>
Get the depth view if available.