RenderTarget

Struct RenderTarget 

pub struct RenderTarget<'a> { /* private fields */ }
A render target that can be rendered to.

Implementations

Source

impl<'a> RenderTarget<'a>

pub fn new( ctx: &'a WgpuContext, color_view: &'a TextureView, depth_view: Option<&'a TextureView>, width: u32, height: u32, format: TextureFormat, ) -> Self

Create a new render target.

pub fn from_surface( ctx: &'a WgpuContext, surface_view: &'a TextureView, depth_texture: Option<&'a DepthTexture>, width: u32, height: u32, format: TextureFormat, ) -> Self

Create a render target from a surface texture.

pub fn width(&self) -> u32

Get the render target width.

pub fn height(&self) -> u32

Get the render target height.

pub fn aspect(&self) -> f32

Get the aspect ratio.

pub fn format(&self) -> TextureFormat

Get the texture format.

pub fn begin_render_pass<'p>( &'a self, encoder: &'p mut CommandEncoder, clear: ClearState, ) -> RenderPass<'p>
where 'a: 'p,

Create a render pass with the given clear state.

pub fn clear(&self, clear: ClearState)

Clear the render target with the given clear state.

pub fn context(&self) -> &WgpuContext

Get a reference to the context.

pub fn color_view(&self) -> &TextureView

Get the color view.

pub fn depth_view(&self) -> Option<&TextureView>

Get the depth view if available.